
# 用于搭建CMake的基础框架，统一架构。

# v0.0.10

*发布IMCA代码构建器*

## v0.0.11

*修复在功能包中创建功能包的BUG*

*修复无法在多层目录下创建功能包的BUG*

*修复功能包无法找到模块的BUG*

## v0.0.12

*修复了功能包重名的问题*

*优化了帮助手册*

-联系作者:Thrent: eel39@yahoo.com

-Github: https://github.com/Thrent33/IMCA_FRAME.git


